<?php
App::uses('EvShopAppController', 'EvShop.Controller');

class ProductsController extends EvShopAppController {

	/**
	 * redefine to allow the index / view page through the auth component!
	 */
	public function beforeFilter() {
		parent::beforeFilter();

		$this->Auth->allow(array('index', 'view'));
	}

	/**
	 * product index page
	 * list all products out
	 *
	 */
	public function index() {
		debug(
			$this->Categories->listing()
		);

//		die('123');
	}

	/**
	 * add the variant management link
	 * prices / stock control (if active)
	 */
	protected function _adminIndexActions() {
		$actions = array(
			'Pricing' => array(
				'cell' => array(
					'class' => 'action pricing'
				),
				'link' => array(
					'url' => array(
						'controller' => 'variants',
						'action' => 'manage'
					),
					'text' => '<i class="fa fa-money"></i>',
					'options' => array(
						'escape' => false
					)
				)
			)
		) + parent::_adminIndexActions();

		return $actions;
	}

	/**
	 * form fields - check for EvTax and auto remove
	 * check for brands setting and auto remove
	 */
	protected function _adminFormFields() {
		$fields = parent::_adminFormFields();

		if (! CakePlugin::loaded('EvTax')) {
			unset($fields['Product.tax_level_id']);
		}

		if (! Configure::read('EvShop.showBrands')) {
			unset($fields['Product.brand_id']);
		}

		return $fields;
	}

	/**
	 * admin populate lookups
	 */
	protected function _adminPopulateLookups() {
		parent::_adminPopulateLookups();

		if (Configure::read('EvShop.showBrands')) {
			$this->set(
				'brands',
				$this->Product->Brand->getForDropDown()
			);
		}
	}

	/**
	 * redefine admin edit to setup inject form
	 * for variants
	 */
	public function admin_edit($id = null) {
		$Model = $this->{$this->modelClass};

		$this->toInject['components']['categories'] = 'EvShop.categories';
		$this->toInject['helpers']['categories'] = 'EvShop.categories';

		if (Configure::read('EvShop.showVariants')) {
			$this->toInject['components']['variants'] = 'EvShop.variants';
			$this->toInject['helpers']['variants'] = 'EvShop.variants';
		}

		if ($this->Session->check('products.options')) {
			$this->request->data['CurrentOptions'] = $this->Session->read('products.options');
		}

		// calculate the redirect to allow pricing redirect if needed
		if ($id === null) {
			$nextId = $Model->find(
				'first',
				array(
					'fields' => 'id',
					'order' => $Model->alias . '.id DESC',
					'callbacks' => false
				)
			);
			$nextId = Hash::get($nextId, $Model->alias . '.id');

			if ($nextId > 0) {
				$nextId++;
			}

			$this->adminRedirect = array(
				'controller' => 'variants',
				'action' => 'manage',
				$nextId
			);
		} else {

			if (! empty($this->request->data['pricing'])) {
				$this->adminRedirect = array(
					'controller' => 'variants',
					'action' => 'manage',
					$id
				);
			}
		}

		parent::admin_edit($id);

		if (! $this->request->is('post') && ! $this->request->is('put')) {
			$this->Session->write(
				'products.options',
				(! empty($this->request->data['Options'])) ? $this->request->data['Options'] : array()
			);
		}

		$this->view = 'EvShop./Products/admin_form';
	}
}
